@@ -36,6 +36,9 @@ SERVICE_VERSIONS = {
         "2020-12-29",
         "2020-06-08"
     ],
+    "anicloud": [
+        "2022-09-23"
+    ],
     "antiddos": [
         "2020-03-09"
     ],
